==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property exact Header value sent by the client must match the specified value exactly.
 */
public data class GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs(
    public val exact: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs> {
    override fun toJava():
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs.builder()
            .exact(exact?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    /**
     * @param value Header value sent by the client must match the specified value exactly.
     */
    @JvmName("lqjqmfjwvmmrmsmd")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value Header value sent by the client must match the specified value exactly.
     */
    @JvmName("wvqgownithngpelu")
    public suspend fun exact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    internal fun build(): GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs =
        GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs(
            exact = exact,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property exact The exact query parameter to match on.
 */
public data class GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs(
    public val exact: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs.builder()
            .exact(exact?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    /**
     * @param value The exact query parameter to match on.
     */
    @JvmName("xgfhlajtqmkgsfwl")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value The exact query parameter to match on.
     */
    @JvmName("wwtoyglqxxstxdkn")
    public suspend fun exact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    internal fun build(): GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs =
        GatewayRouteSpecHttp2RouteMatchQueryParameterMatchArgs(
            exact = exact,
        )
}
